// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: GPL-3.0-or-later

#include "roles.h"
#include <QDebug>

Roles::Roles()
{
    qDebug() << "Roles::Roles - Entry";
}